<?php

/**
 * @file
 * Menu callbacks for the paypal_roles module.
 */

/**
 * Callback function to handle PayPal IPN requests.
 */
function paypal_roles_ipn_listener_callback() {
  // STEP 1: read POST data.
  // Reading POSTed data directly from $_POST causes serialization issues with array data in the POST.
  // Instead, read raw POST data from the input stream.
  $raw_post_data = file_get_contents('php://input');
  $raw_post_array = explode('&', $raw_post_data);

  $myPost = array();
  foreach ($raw_post_array as $keyval) {
    $keyval = explode('=', $keyval);
    if (count($keyval) == 2) {
      $myPost[$keyval[0]] = urldecode($keyval[1]);
    }
  }

  // Read the IPN message sent from PayPal and prepend 'cmd=_notify-validate'.
  $req = 'cmd=_notify-validate';
  if (function_exists('get_magic_quotes_gpc')) {
    $get_magic_quotes_exists = TRUE;
  }
  else {
    $get_magic_quotes_exists = FALSE;
  }

  foreach ($myPost as $key => $value) {
    if ($get_magic_quotes_exists == TRUE && get_magic_quotes_gpc() == 1) {
      $value = urlencode(stripslashes($value));
    }
    else {
      $value = urlencode($value);
    }
    $req .= "&$key=$value";
  }

  // STEP 2: POST IPN data back to PayPal to validate.

  if (variable_get('paypal_roles_sandbox', 1) == "1") {
    $url = 'https://www.sandbox.paypal.com/cgi-bin/webscr';
  }
  else {
    $url = 'https://www.paypal.com/cgi-bin/webscr';
  }

  $ch = curl_init($url);
  curl_setopt($ch, CURLOPT_HTTP_VERSION, CURL_HTTP_VERSION_1_1);
  curl_setopt($ch, CURLOPT_POST, 1);
  curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
  curl_setopt($ch, CURLOPT_POSTFIELDS, $req);
  curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 1);
  curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 2);
  curl_setopt($ch, CURLOPT_FORBID_REUSE, 1);
  curl_setopt($ch, CURLOPT_HTTPHEADER, array('Connection: Close'));

  // In wamp-like environments that do not come bundled with root authority certificates,
  // please download 'cacert.pem' from "http://curl.haxx.se/docs/caextract.html" and set
  // the directory path of the certificate as shown below:
  // curl_setopt($ch, CURLOPT_CAINFO, dirname(__FILE__) . '/cacert.pem');
  if (!($res = curl_exec($ch))) {
    // error_log("Got " . curl_error($ch) . " when processing IPN data");
    curl_close($ch);
    drupal_exit();
  }
  curl_close($ch);

  // STEP 3: Inspect IPN validation result and act accordingly.

  $log = variable_get('paypal_roles_log_failed_ipn', 1);

  if (strcmp($res, "VERIFIED") == 0) {
    // Check whether the payment_status is Completed.
    if (!isset($_POST['payment_status']) || strtoupper($_POST['payment_status']) != "COMPLETED") {
      if ((int) $log === 1) {
        watchdog('PAYPAL_ROLES', t('The response from IPN was: "payment_status" is not completed.'));
        watchdog('PAYPAL_ROLES_IPN', var_export($_POST, TRUE));
      }
      drupal_exit();
    }

    // Check that txn_id has not been previously processed.
    if (!isset($_POST['txn_id']) || empty($_POST['txn_id'])) {
      if ((int) $log === 1) {
        watchdog('PAYPAL_ROLES', t('The response from IPN was: Invalid "txn_id".'));
        watchdog('PAYPAL_ROLES_IPN', var_export($_POST, TRUE));
      }
      drupal_exit();
    }

    // Check that txn_id exists.
    $txn = paypal_roles_payments_load($_POST['txn_id']);
    if ($txn) {
      if ((int) $log === 1) {
        watchdog('PAYPAL_ROLES', t('The response from IPN was: "txn_id" is duplicated.'));
        watchdog('PAYPAL_ROLES_IPN', var_export($_POST, TRUE));
      }
      drupal_exit();
    }

    // Check that receiver_email is your Primary PayPal email.
    if (variable_get('paypal_roles_sandbox', 1) == "1") {
      $remail = variable_get('paypal_roles_s_email', '');
    }
    else {
      $remail = variable_get('paypal_roles_l_email', '');
    }
    if (!isset($_POST['receiver_email']) || $_POST['receiver_email'] != $remail) {
      if ((int) variable_get('paypal_roles_validate_primary_email', 1) === 1) {
        if ((int) $log === 1) {
          watchdog('PAYPAL_ROLES', t('The response from IPN was: Invalid "receiver_email".'));
          watchdog('PAYPAL_ROLES_IPN', var_export($_POST, TRUE));
        }
        drupal_exit();
      }
    }

    // Check that Membership Package subscribed for is valid.
    if (!isset($_POST['item_number'])) {
      if ((int) $log === 1) {
        watchdog('PAYPAL_ROLES', t('The response from IPN was: Invalid "item_number".'));
        watchdog('PAYPAL_ROLES_IPN', var_export($_POST, TRUE));
      }
      drupal_exit();
    }
    $ml = paypal_roles_memberships_load($_POST['item_number']);
    if (!$ml) {
      if ((int) $log === 1) {
        watchdog('PAYPAL_ROLES', t('The response from IPN was: Invalid "item_number".'));
        watchdog('PAYPAL_ROLES_IPN', var_export($_POST, TRUE));
      }
      drupal_exit();
    }

    // Get Drupal user.
    // 1. try to load user by $_POST['subscr_id']
    // 2. try to load user by $_POST['payer_id']
    // 3. try to load user by $_POST['custom']
    // 4. try to load user by $_POST['payer_email']
    // 5. user is new user, needs registration

    $scr = NULL;
    if (isset($_POST['subscr_id'])) {
      $scr = paypal_roles_payer_load($_POST['subscr_id']);
    }

    $pyr = NULL;
    if (isset($_POST['payer_id'])) {
      $pyr = paypal_roles_payer_load($_POST['payer_id']);
    }

    // Check that Drupal user exists or not.
    if (isset($scr->uid) && $scr->uid > 0) {
      $user = user_load($scr->uid);
    }
    else if (isset($pyr->uid) && $pyr->uid > 0) {
      $user = user_load($pyr->uid);
    }
    else if (isset($_POST['custom']) && valid_email_address($_POST['custom'])) {
      $user = user_load_by_mail($_POST['custom']);
    }
    else if ($_POST['payer_email']) {
      $user = user_load_by_mail($_POST['payer_email']);
    }
    else {
      $user = FALSE;
    }

    $ipn = paypal_roles_save_ipn_message($user);
    if ($ipn) {
      paypal_roles_manage_roles_by_users($ipn->uid);
    }
  }
  else if (strcmp($res, "INVALID") == 0) {
    if ((int) $log === 1) {
      watchdog('PAYPAL_ROLES', t('The response from IPN was') . ': ' . $res);
      watchdog('PAYPAL_ROLES_IPN', var_export($_POST, TRUE));
    }
    drupal_exit();
  }
}
